@@ -473,7 +473,7 @@ void ApplicationCacheHost::abort()
 
 bool ApplicationCacheHost::isApplicationCacheEnabled()
 {
-    return m_documentLoader->frame()->settings()
+    return m_documentLoader->frame() && m_documentLoader->frame()->settings()
            && m_documentLoader->frame()->settings()->offlineWebApplicationCacheEnabled();
 }
 
