@@ -271,6 +271,7 @@ QNetworkReplyWrapper::QNetworkReplyWrapper(QNetworkReplyHandlerCallQueue* queue,
     connect(m_reply, SIGNAL(finished()), this, SLOT(setFinished()));
     connect(m_reply, SIGNAL(finished()), this, SLOT(receiveMetaData()));
     connect(m_reply, SIGNAL(readyRead()), this, SLOT(receiveMetaData()));
+    connect(m_reply, SIGNAL(destroyed()), this, SLOT(replyDestroyed()));
 }
 
 QNetworkReplyWrapper::~QNetworkReplyWrapper()
@@ -285,12 +286,11 @@ QNetworkReply* QNetworkReplyWrapper::release()
     if (!m_reply)
         return 0;
 
-    resetConnections();
+    m_reply->disconnect(this);
     QNetworkReply* reply = m_reply;
     m_reply = 0;
     m_sniffer = nullptr;
 
-    reply->setParent(0);
     return reply;
 }
 
@@ -300,10 +300,10 @@ void QNetworkReplyWrapper::synchronousLoad()
     receiveMetaData();
 }
 
-void QNetworkReplyWrapper::resetConnections()
+void QNetworkReplyWrapper::stopForwarding()
 {
     if (m_reply) {
-        // Disconnect all connections except the one to setFinished() slot.
+        // Disconnect all connections that might affect the ResourceHandleClient.
         m_reply->disconnect(this, SLOT(receiveMetaData()));
         m_reply->disconnect(this, SLOT(didReceiveFinished()));
         m_reply->disconnect(this, SLOT(didReceiveReadyRead()));
@@ -314,8 +314,7 @@ void QNetworkReplyWrapper::resetConnections()
 void QNetworkReplyWrapper::receiveMetaData()
 {
     // This slot is only used to receive the first signal from the QNetworkReply object.
-    resetConnections();
-
+    stopForwarding();
 
     WTF::String contentType = m_reply->header(QNetworkRequest::ContentTypeHeader).toString();
     m_encoding = extractCharsetFromMediaType(contentType);
@@ -368,6 +367,12 @@ void QNetworkReplyWrapper::setFinished()
     m_reply->setProperty("_q_isFinished", true);
 }
 
+void QNetworkReplyWrapper::replyDestroyed()
+{
+    m_reply = 0;
+    m_sniffer = nullptr;
+}
+
 void QNetworkReplyWrapper::emitMetaDataChanged()
 {
     QueueLocker lock(m_queue);
@@ -398,7 +403,7 @@ void QNetworkReplyWrapper::didReceiveReadyRead()
 void QNetworkReplyWrapper::didReceiveFinished()
 {
     // Disconnecting will make sure that nothing will happen after emitting the finished signal.
-    resetConnections();
+    stopForwarding();
     m_queue->push(&QNetworkReplyHandler::finish);
 }
 
