@@ -1480,14 +1480,17 @@ void QWebFrame::print(QPrinter *printer) const
 */
 QVariant QWebFrame::evaluateJavaScript(const QString& scriptSource)
 {
-    ScriptController *proxy = d->frame->script();
+    ScriptController* scriptController = d->frame->script();
     QVariant rc;
-    if (proxy) {
+    if (scriptController) {
         int distance = 0;
-        JSC::JSValue v = d->frame->script()->executeScript(ScriptSourceCode(scriptSource)).jsValue();
-        JSC::ExecState* exec = proxy->globalObject(mainThreadNormalWorld())->globalExec();
+        ScriptValue value = scriptController->executeScript(ScriptSourceCode(scriptSource));
+        JSC::ExecState* exec = scriptController->globalObject(mainThreadNormalWorld())->globalExec();
         JSValueRef* ignoredException = 0;
-        rc = JSC::Bindings::convertValueToQVariant(toRef(exec), toRef(exec, v), QMetaType::Void, &distance, ignoredException);
+        JSC::JSLock::lock(exec);
+        JSValueRef valueRef = toRef(exec, value.jsValue());
+        JSC::JSLock::unlock(exec);
+        rc = JSC::Bindings::convertValueToQVariant(toRef(exec), valueRef, QMetaType::Void, &distance, ignoredException);
     }
     return rc;
 }
